# Security Policy

We only support the current major version and one major version before the current version.

If you are running versions older than that, you should upgrade to a newer version.

## Supported Versions

| Version | Support Status |
|:-------:|:--------------:|
| 1.x     |       ✅       |

## Known Vulnerabilities

None

## Reporting a Vulnerability

Report vulnerabilities via the GitHub [Security](https://github.com/JerilynFranz/python-autopypath/security)
link on the [python-autopypath GitHub repository page](https://github.com/JerilynFranz/python-autopypath/)
